internal

package
v0.1.2-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package internal contains the main application logic for the CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(ctx context.Context, getenv func(string) string) error

Run is the main application logic, extracted for testability. It accepts OS dependencies as parameters (context, env lookup).

Types

This section is empty.

Jump to