config

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package config handles daco project configuration.

Index

Constants

const CurrentConfigVersion = 1

CurrentConfigVersion is the current version of the config file format.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Version int    `yaml:"version"`
	Path    string `yaml:"path,omitempty"`
}

Config represents the daco.yaml project configuration file.

func Load

func Load(path string) (*Config, error)

Load reads a Config from a file path.

func (*Config) Save

func (c *Config) Save(path string) error

Save writes the Config to a file path.

func (*Config) Validate

func (c *Config) Validate() error

Validate checks the configuration for required fields and valid values.

Jump to